/*! \file splash.c
 *  \brief Utilities Splash.
 *         Dingoo Library.
 *
 *  \version 0.1
 *
 *  Dingoo Splash driver
 *
 *   Vieju.net Splash - Dingoo Port
 *  (c) Copyright 2009 David Colmenero (aka D_Skywalk)
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <SDL.h>
#include <SDL_image.h>

#include "SDL_splash.h"
#include "image.h"

SDL_Surface *screen_base = NULL;
SDL_Surface *splash = NULL;
SDL_Surface *back = NULL;

#define true 1
#define false 0

//-------------------------------------------

int LoadGFX (SDL_Surface ** img, const unsigned char my_png[], int my_png_size)
{
  //loading PNG from memory
  *img = IMG_Load_RW( SDL_RWFromConstMem( my_png, my_png_size), 1);

  if(!*img)
  {
    printf("ERROR_PNG: on load... \n");
    return false;
  }

  
  //printf("DEBUG_PNG: w:%i, h:%i\n", (*img)->w, (*img)->h);

  //back: black screen
  const SDL_PixelFormat *pf = screen_base->format;
  back = SDL_CreateRGBSurface(SDL_SWSURFACE, (*img)->w, (*img)->h, 16, pf->Rmask, pf->Gmask, pf->Bmask, pf->Amask);
  SDL_FillRect(back, NULL, SDL_MapRGB(back->format, 0,0,0));

  return true;
}

void FreeGFX (SDL_Surface ** img)
{
  SDL_FreeSurface(back);
  SDL_FreeSurface(*img);
  back = *img = NULL;
}


void DrawBitmap (SDL_Surface * img, int y) 
{
   if(!y) //si no hay y, centrado
      y = ((screen_base->h - img->h)/2);

   SDL_Rect dr = { ((screen_base->w - img->w)/2) , y, img->w, img->h};
   SDL_BlitSurface(img, NULL, screen_base, &dr);
}

void fadeOff(SDL_Surface * img)
{
  int c;

  for(c = 0; c < 256 ; c += 8)
  {
     DrawBitmap (back, 0);
     DrawBitmap (img, 0);

     SDL_SetAlpha(back,SDL_SRCALPHA, c); //apply alpha to background (PNG-24 can't be used with an alpha channel)
     DrawBitmap (back, 0);

     SDL_Flip(screen_base);

     SDL_SetAlpha(back, 0, SDL_ALPHA_OPAQUE); //set original
     SDL_Delay(25);
  }
}

void screenShow(SDL_Surface * img)
{

  DrawBitmap (img, 0);
  SDL_Flip(screen_base);
  SDL_Delay(1800);

}

//-----------------------------------------------------------------

void ShowSplash (SDL_Surface * screen)
{
  screen_base = screen;

  if(!LoadGFX(&splash, viejusplashfinal, viejusplashfinal_size)) //load splash
     return;

  screenShow(splash);

  fadeOff(splash);

  FreeGFX (&splash);

}


